%define snortroot /var/chroot/snort

Summary:	A libpcap-based packet sniffer/logger.
Name:		snort
Version:	2.3.3
Release:	9
License:	GPL
Group:		Applications/Internet
Source0:	http://www.snort.org/dl/current/%{name}-%{version}.tar.gz
Source1:	snortd-init-gd-7
Patch0:		snort-2.3.3-snort.conf-gd.1.diff
Patch1:		snort-2.3.3-lib64-gd-1.diff
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root
Requires:	libpcap >= 0.4
BuildRequires:	libpcap >= 0.4
Obsoletes:	snort-rules

%description
Snort is a libpcap-based packet sniffer/logger which 
can be used as a lightweight network intrusion detection system. 
It features rules based logging and can perform protocol analysis, 
content searching/matching and can be used to detect a variety of 
attacks and probes, such as buffer overflows, stealth port scans, 
CGI attacks, SMB probes, OS fingerprinting attempts, and much more. 
Snort has a real-time alerting capabilty, with alerts being sent to syslog, 
a seperate "alert" file, or as a WinPopup message via Samba's smbclient

%files
  %defattr(0444,root,root,0555)
  %doc ChangeLog LICENSE doc/*
  %doc %{_mandir}/man8/snort.8*

  %attr(500,root,root)		%{snortroot}/sbin/*
  %attr(750,root,admin)		%dir %{snortroot}/var/log/snort
  %attr(750,snort,admin)	%dir %{snortroot}/var/log/snort/archive

  %attr(640,root,snort)		%config(noreplace)     %{snortroot}/etc/snort.conf
  %attr(640,root,snort)		%config(noreplace)     %{snortroot}/etc/snort.conf.gd
  %attr(640,root,snort)		%config %{snortroot}/etc/*.config
  %attr(640,root,snort)		%config %{snortroot}/etc/*.map
  %attr(640,root,snort)		%config %{snortroot}/etc/*.rules
  %attr(640,root,snort)		%config %{snortroot}/etc/generators
  %attr(640,root,snort)		%config %{snortroot}/etc/sid
  %attr(640,root,snort)		%config %{snortroot}/etc/threshold.conf
  %attr(700,root,root)		%{_sysconfdir}/init.d/snortd

%prep
%setup -q
%patch0 -p1
%patch1 -p1

%build
  autoconf

  CFLAGS="$RPM_OPT_FLAGS" \
  ./configure \
	--prefix=%{snortroot} \
	--with-mysql \
	--with-openssl \
	--enable-smbalerts \
	--bindir=%{snortroot}/sbin \
	--mandir=%{_mandir}
  make %{?_smp_mflags}

%install
  [ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

  mkdir -p $RPM_BUILD_ROOT/%{snortroot}/{sbin,doc,etc,var/log/snort/archive}
  mkdir -p $RPM_BUILD_ROOT/%{_sysconfdir}/init.d

  make prefix=$RPM_BUILD_ROOT/%{snortroot} \
       bindir=$RPM_BUILD_ROOT/%{snortroot}/sbin \
       sysconfdir=$RPM_BUILD_ROOT/%{snortroot}/%{_sysconfdir} \
       mandir=$RPM_BUILD_ROOT/%{_mandir} install

  install %{SOURCE1} $RPM_BUILD_ROOT/%{_sysconfdir}/init.d/snortd

  # Install configuration files.
  pushd etc
    for i in *conf *.config *map generators sid
    do
      install -m0640 $i $RPM_BUILD_ROOT/%{snortroot}/etc/$i
    done
  popd

  # Install base rules.
  pushd rules
    install -d $RPM_BUILD_ROOT/%{snortroot}/etc
    install *.rules $RPM_BUILD_ROOT/%{snortroot}/etc
  popd

  echo "SNORT_INTERFACE=eth0" > $RPM_BUILD_ROOT/%{snortroot}/etc/snort.conf.gd

%pre
  if [ $1 = 1 ] ; then 
    useradd -M -r -d %{snortroot} -s /bin/false -c "Snort User" snort 2> /dev/null || true
    groupadd -r snort 2> /dev/null || true
  fi

%post
  chown -R snort.snort %{snortroot}/var/log/snort

  if [ -f /var/lock/subsys/snort ]; then
    /etc/init.d/snortd restart || true
  fi

%preun
  if [ $1 = 0 ] ; then
    if [ -f /var/lock/subsys/snort ] ; then
      /etc/init.d/snortd stop || true
    fi
    /sbin/chkconfig --del snortd || true
  fi

%postun
  if [ $1 = 0 ] ; then
    userdel snort 2> /dev/null || true
    groupdel snort 2> /dev/null || true
    if [ -d %{snortroot} ] ; then
      rm -rf %{snortroot}
    fi
  fi

%clean
  [ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

%changelog
* Fri Sep 23 2005 Ryan W. Maple <ryan@guardiandigital.com>
- Version 2.3.3, Release 9
  - Fix building on 64bit architectures.

* Thu Sep 22 2005 Ryan W. Maple <ryan@guardiandigital.com>
- Version 2.3.3, Release 7
  - Actually fix the initscript...

* Thu Sep 22 2005 Ryan W. Maple <ryan@guardiandigital.com>
- Version 2.3.3, Release 6
  - chdir into the chroot before we start it so it plays nice with SELinux.
    Fixes #0000885.

* Thu Sep 15 2005 Pete O'Hara <pete@guardiandigital.com>
- Version 2.3.3, Release 5
  - In %pre changed "$1 = 0" to "$1 = 1" for execution at
    install
  - In %preun added shutdown daemon only if it is running
  - In %postun remove snort root directory

* Tue Sep 13 2005 Ryan W. Maple <ryan@guardiandigital.com>
- Version 2.3.3, Release 4
  - We don't ship barnyard anymore so update the initscript,
    fixes #0000807.

* Thu Sep 01 2005 Ryan W. Maple <ryan@guardiandigital.com>
- Version 2.3.3, Release 3
  - Rebuild against latest libmysqlclient (really this time).

* Tue Aug 30 2005 Ryan W. Maple <ryan@guardiandigital.com>
- Version 2.3.3, Release 2
  - Rebuild against latest libmysqlclient.

* Tue Jun 28 2005 Ryan W. Maple <ryan@guardiandigital.com>
- Version 2.3.3, Release 1
  - Initial build for EnGarde Secure Linux 3.0.
